@@ -190,7 +190,7 @@ func (p *HCLProvider) AddMetadata(metadata *schema.ProjectMetadata) {
 // LoadResources calls a hcl.Parser to parse the directory config files into hcl.Blocks. It then builds a shallow
 // representation of the terraform plan JSON files from these Blocks, this is passed to the PlanJSONProvider.
 // The PlanJSONProvider uses this shallow representation to actually load Infracost resources.
-func (p *HCLProvider) LoadResources(usage map[string]*schema.UsageData) ([]*schema.Project, error) {
+func (p *HCLProvider) LoadResources(usage schema.UsageMap) ([]*schema.Project, error) {
 	jsons := p.LoadPlanJSONs()
 
 	var projects = make([]*schema.Project, len(jsons))
@@ -206,7 +206,7 @@ func (p *HCLProvider) LoadResources(usage map[string]*schema.UsageData) ([]*sche
 		}
 
 		if p.scanner != nil {
-			err := p.scanner.ScanPlan(project, j.JSON)
+			err := p.scanner.ScanPlan(project)
 			if err != nil {
 				p.logger.WithError(err).Debugf("failed to scan Terraform project %s", project.Name)
 			}
@@ -217,7 +217,7 @@ func (p *HCLProvider) LoadResources(usage map[string]*schema.UsageData) ([]*sche
 	return projects, nil
 }
 
-func (p *HCLProvider) parseResources(parsed HCLProject, usage map[string]*schema.UsageData) *schema.Project {
+func (p *HCLProvider) parseResources(parsed HCLProject, usage schema.UsageMap) *schema.Project {
 	project := p.newProject(parsed)
 
 	partialPastResources, partialResources, err := p.planJSONParser.parseJSON(parsed.JSON, usage)
@@ -318,13 +318,7 @@ func (p *HCLProvider) Modules() []HCLProject {
 	numJobs := len(p.parsers)
 	runInParallel := parallelism > 1 && numJobs > 1
 	if runInParallel && !runCtx.Config.IsLogging() {
-		if runInParallel && !p.config.SuppressLogging {
-			fmt.Fprintln(os.Stderr, "Running multiple projects in parallel, so log-level=info is enabled by default.")
-			fmt.Fprintln(os.Stderr, "Run with INFRACOST_PARALLELISM=1 to disable parallelism to help debugging.")
-			fmt.Fprintln(os.Stderr)
-		}
-
-		p.logger.Logger.SetLevel(log.InfoLevel)
+		// set the config level to info so that the spinners don't report to the console.
 		p.ctx.RunContext.Config.LogLevel = "info"
 	}
 
